diff --git a/Common/DefaultOptions.h b/Common/DefaultOptions.h
index 2ccab8877c2c6ff08be5ce3b8495f0e23f7979d9..d601bc028aef409c2b53f504d3f7ce330c7fb844 100644
--- a/Common/DefaultOptions.h
+++ b/Common/DefaultOptions.h
@@ -639,6 +639,8 @@ StringXNumber GeneralOptions_Number[] = {
     "X position of small axes (use negative values for right alignment)" },
   { F|O, "SmallAxesPositionY" , opt_general_small_axes_position1 , -40. ,
     "Y position of small axes (use negative values for bottom alignment)" },
+  { F|O, "SmallAxesSize" , opt_general_small_axes_size , 30. ,
+    "Size (in pixels) of small axes" },
   { F|S, "SolverPositionX" , opt_general_solver_position0 , 650. , 
     "Horizontal position (in pixels) of the upper left corner of the solver windows" }, 
   { F|S, "SolverPositionY" , opt_general_solver_position1 , 150. ,
diff --git a/Common/Options.cpp b/Common/Options.cpp
index a068212bad215fada0a0a2318c921db22a0416cd..a047d8fe4445d1bd8aabfe5a4e1ae9fb7575dc68 100644
--- a/Common/Options.cpp
+++ b/Common/Options.cpp
@@ -1,4 +1,4 @@
-// $Id: Options.cpp,v 1.223 2005-01-01 19:35:27 geuzaine Exp $
+// $Id: Options.cpp,v 1.224 2005-01-02 18:10:12 geuzaine Exp $
 //
 // Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
 //
@@ -2499,6 +2499,13 @@ double opt_general_small_axes_position1(OPT_ARGS_NUM)
   return CTX.small_axes_pos[1];
 }
 
+double opt_general_small_axes_size(OPT_ARGS_NUM)
+{
+  if(action & GMSH_SET)
+    CTX.small_axes_size = (int)val;
+  return CTX.small_axes_size;
+}
+
 double opt_general_quadric_subdivisions(OPT_ARGS_NUM)
 {
   if(action & GMSH_SET)
diff --git a/Common/Options.h b/Common/Options.h
index 5ce0d5a092f4e16661b4c71ad79192cd6cab29c5..514d9750ce3cfeefa212d32fae62ff2e9a296778 100644
--- a/Common/Options.h
+++ b/Common/Options.h
@@ -271,6 +271,7 @@ double opt_general_axes(OPT_ARGS_NUM);
 double opt_general_small_axes(OPT_ARGS_NUM);
 double opt_general_small_axes_position0(OPT_ARGS_NUM);
 double opt_general_small_axes_position1(OPT_ARGS_NUM);
+double opt_general_small_axes_size(OPT_ARGS_NUM);
 double opt_general_quadric_subdivisions(OPT_ARGS_NUM);
 double opt_general_double_buffer(OPT_ARGS_NUM);
 double opt_general_alpha_blending(OPT_ARGS_NUM);
diff --git a/Graphics/Axes.cpp b/Graphics/Axes.cpp
index 63e83d29577befb23965fe95590d17577d46dfef..7bf404925c14a0e1f39ea439bceda24164584b24 100644
--- a/Graphics/Axes.cpp
+++ b/Graphics/Axes.cpp
@@ -1,4 +1,4 @@
-// $Id: Axes.cpp,v 1.24 2005-01-01 19:35:29 geuzaine Exp $
+// $Id: Axes.cpp,v 1.25 2005-01-02 18:10:12 geuzaine Exp $
 //
 // Copyright (C) 1997-2005 C. Geuzaine, J.-F. Remacle
 //
@@ -123,7 +123,7 @@ void Draw_SmallAxes(void)
 {
   double l, o, xx, xy, yx, yy, zx, zy, cx, cy;
 
-  l = 30;
+  l = CTX.small_axes_size;
   o = 2;
 
   if(CTX.small_axes_pos[0] > 0)
diff --git a/doc/texinfo/opt_general.texi b/doc/texinfo/opt_general.texi
index e153576cf974eef9c80b4e2bc93b7df48fa156c8..16b36af3fc72260881a3283b6986f6b0d048b4b2 100644
--- a/doc/texinfo/opt_general.texi
+++ b/doc/texinfo/opt_general.texi
@@ -634,6 +634,11 @@ Y position of small axes (use negative values for bottom alignment)@*
 Default value: @code{-40}@*
 Saved in: @code{General.OptionsFileName}
 
+@item General.SmallAxesSize
+Size (in pixels) of small axes@*
+Default value: @code{30}@*
+Saved in: @code{General.OptionsFileName}
+
 @item General.SolverPositionX
 Horizontal position (in pixels) of the upper left corner of the solver windows@*
 Default value: @code{650}@*
diff --git a/doc/texinfo/opt_plugin.texi b/doc/texinfo/opt_plugin.texi
index 2fa5419b7e6722d3f5a79e9a257855ca32c70136..a0003b9a8584f0454b352efe6f289b8f4fc8bdd6 100644
--- a/doc/texinfo/opt_plugin.texi
+++ b/doc/texinfo/opt_plugin.texi
@@ -259,9 +259,11 @@ in the view `iView' to the expression
 mathematical functions (Exp, Log, Sqrt, Sin,
 Cos, Fabs, etc.) and operators (+, -, *, /, ^),
 `Expression' can contain the symbols x, y, z
-and v, which represent the three spatial
-coordinates and the value of the `TimeStep'-th
-component of the field, respectively. If
+(which represent the current position), v (which
+represents the `Component'-th component of
+the field at the `TimeStep'-th time step), and v0,
+v1, v2, ..., vn (which represent the n components
+of the field at the `TimeStep'-th time step). If
 `iView' < 0, the plugin is run on the current
 view.
 
diff --git a/doc/texinfo/opt_solver.texi b/doc/texinfo/opt_solver.texi
index 1d2218dafb710cd534e6bd3d3fdaddb853e47942..7743c53ab2358f7f22960677477fd3f5b940afd2 100644
--- a/doc/texinfo/opt_solver.texi
+++ b/doc/texinfo/opt_solver.texi
@@ -13,7 +13,7 @@ Saved in: @code{General.OptionsFileName}
 Help string for solver 0@*
 Default value: @code{"A General environment for the treatment of
 Discrete Problems.
-Copyright (C) 1997-2004
+Copyright (C) 1997-2005
 Patrick Dular and Christophe Geuzaine.
 Visit http://www.geuz.org/getdp/ for more info"}@*
 Saved in: @code{General.OptionsFileName}
diff --git a/Common/Context.h b/Common/Context.h
index 01e8d530490c862860506cd4c402abda7a00d475..63e91f0889629d918ec42e210cd5ebb6910a9c4b 100644
--- a/Common/Context.h
+++ b/Common/Context.h
@@ -113,7 +113,7 @@ public :
   int draw_bbox;              // always draw the bounding boxes?
   int fast_redraw;            // only draw the bbox when rotating/panning the model?
   int axes, small_axes;       // draw axes? 
-  int small_axes_pos[2];      // small axes position 
+  int small_axes_pos[2], small_axes_size; // small axes position and size
   int threads, threads_lock;  // threads?, lock (should be a mutex...) 
   int alpha;                  // enable alpha blending 
   double zoom_factor;         // mouse2 zoom coefficient